# Onboarding Guide for SAP LeanIX Application Portfolio Management
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management#overview)
  * [Onboarding Progress and Data Quality](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management#onboarding-progress-and-data-quality)


The onboarding guide offers a streamlined onboarding process for SAP LeanIX Application Portfolio Management, providing step-by-step instructions, resources, and progress tracking.
